Stan Math Library: stan/math/rev/mat/fun/crossprod.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
crossprod.hpp File Reference
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/mat/fun/tcrossprod.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
matrix_v | stan::math::crossprod (const matrix_v &M)
| Returns the result of pre-multiplying a matrix by its own transpose. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.